# PowerAuth SDK for Mobile Apps

In order to connect to the [PowerAuth](https://www.wultra.com/product/powerauth-mobile-security-suite) service, mobile applications need to perform the required network and cryptographic processes, as described in the PowerAuth documentation. To simplify implementation of these processes, developers can use iOS and Android libraries from this repository.

## Integration Tutorials

- [PowerAuth SDK for iOS and tvOS Apps](./docs/PowerAuth-SDK-for-iOS.md)
- [PowerAuth SDK for iOS and tvOS Extensions](./docs/PowerAuth-SDK-for-iOS-Extensions.md)
- [PowerAuth SDK for watchOS](./docs/PowerAuth-SDK-for-watchOS.md)
- [PowerAuth SDK for Android Apps](./docs/PowerAuth-SDK-for-Android.md)

Related projects

- [PowerAuth SDK for React Native](https://github.com/wultra/react-native-powerauth-mobile-sdk)

## Migration guides

If you need to upgrade PowerAuth Mobile SDK to a newer version, you can check following migration guides:

- [Migration from version `1.7.x` to `1.8.x`](docs/Migration-from-1.7-to-1.8.md)
- [Migration from version `1.6.x` to `1.7.x`](docs/Migration-from-1.6-to-1.7.md)
- [Migration from version `1.5.x` to `1.6.x`](docs/Migration-from-1.5-to-1.6.md)
- [Migration from version `1.4.x` to `1.5.x`](docs/Migration-from-1.4-to-1.5.md)
- [Migration from version `1.3.x` to `1.4.x`](docs/Migration-from-1.3-to-1.4.md)
- [Migration from version `1.2.x` to `1.3.x`](docs/Migration-from-1.2-to-1.3.md)
- [Migration from version `1.1.x` to `1.2.x`](docs/Migration-from-1.1-to-1.2.md)
- [Migration from version `1.0.x` to `1.1.x`](docs/Migration-from-1.0-to-1.1.md)
- [Migration from version `0.20.x` to `1.0.x`](docs/Migration-from-0.20-to-1.0.md)
- [Migration from version `0.19.x` to `0.20.x`](docs/Migration-from-0.19-to-0.20.md)

## Support and Compatibility

| Mobile SDK | Protocol | PowerAuth Server    | Support Status                    |
|------------|----------|---------------------|-----------------------------------|
| `1.8.x`    | `V3.2`   | `1.5+`              | Fully supported                   |
| `1.7.x`    | `V3.1`   | `0.24+`             | Security & Functionality bugfixes |
| `1.6.x`    | `V3.1`   | `0.24+`             | Security bugfixes                 |
| `1.5.x`    | `V3.1`   | `0.24+`             | Security bugfixes                 |
| `1.4.x`    | `V3.1`   | `0.24+`             | Security bugfixes                 |
| `1.3.x`    | `V3.1`   | `0.23+`             | Not supported                     |
| `1.2.x`    | `V3.0`   | `0.22+`             | Not supported                     |
| `1.1.x`    | `V3.0`   | `0.21+`             | Not supported                     |
| `0.20.x`   | `V2.1`   | `0.18+`             | Not supported                     |

## License

All sources are licensed using Apache 2.0 license, you can use them with no restriction. If you are using PowerAuth 2.0, please let us know. We will be happy to share and promote your project.

## Contact

If you need any assistance, do not hesitate to drop us a line at [hello@wultra.com](mailto:hello@wultra.com).

### Security Disclosure

If you believe you have identified a security vulnerability with PowerAuth, you should report it as soon as possible via email to [support@wultra.com](mailto:support@wultra.com). Please do not post it to a public issue tracker.